@@ -12,7 +12,7 @@ from datetime import datetime, timedelta
 from decimal import Decimal
 from typing import List, Tuple, Any, Union
 
-from bson import codec_options, decimal128
+from bson import codec_options, ObjectId, decimal128
 from motor.core import AgnosticCollection
 from motor.motor_asyncio import AsyncIOMotorClient
 from pymongo import InsertOne, UpdateMany, DeleteMany, IndexModel
@@ -419,6 +419,20 @@ class MongoDBDecimalCodec(codec_options.TypeCodec):
         return value.to_decimal()
 
 
+class IDCodec(DefaultCodec):
+    """ 唯一主键编解码类 """
+    type_name = 'id'
+
+    def on_load(self, data: str) -> ObjectId:
+        return ObjectId(data)
+
+    def on_to_json(self, data: ObjectId) -> str:
+        return str(data)
+
+    def on_to_db(self, data: ObjectId) -> ObjectId:
+        return data
+
+
 class DecimalCodec(DefaultCodec):
     """ 十进制数字编解码类 """
     type_name = 'decimal'
@@ -461,8 +475,9 @@ class MongoDB(Database):
     database_type: str = 'mongodb'
 
     def init(self, model_class, **kwargs):
-        for codec_class in (DecimalCodec, DatetimeCodec):
+        for codec_class in (IDCodec, DecimalCodec, DatetimeCodec):
             CodecFactory.set(codec_class, True)
+        model_class.id_field = '_id'
         return self
 
     def connect(self, uri: str) -> 'Database':
@@ -480,6 +495,10 @@ class MongoDB(Database):
         self.client = None
         self.database = None
 
+    def new_id(self, id_prefix='') -> ObjectId:
+        """ 获取一个新的id """
+        return ObjectId()
+
     def new_query(self, table_name: str) -> Query:
         """ 获取一个新的查询 """
         return MongoDBQuery(table_name)
